/* This is a GENERATED file. */
/* Generated data (by glib-mkenums) */

#include "gwyprocesstypes.h"

#include "./gwyprocessenums.h"

GType
gwy_merge_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_MERGE_UNION, "GWY_MERGE_UNION", "union" },
            { GWY_MERGE_INTERSECTION, "GWY_MERGE_INTERSECTION", "intersection" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyMergeType", values);
    }
    return etype;
}

GType
gwy_masking_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_MASK_EXCLUDE, "GWY_MASK_EXCLUDE", "exclude" },
            { GWY_MASK_INCLUDE, "GWY_MASK_INCLUDE", "include" },
            { GWY_MASK_IGNORE, "GWY_MASK_IGNORE", "ignore" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyMaskingType", values);
    }
    return etype;
}

GType
gwy_watershed_state_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_WATERSHED_STATE_INIT, "GWY_WATERSHED_STATE_INIT", "init" },
            { GWY_WATERSHED_STATE_LOCATE, "GWY_WATERSHED_STATE_LOCATE", "locate" },
            { GWY_WATERSHED_STATE_MIN, "GWY_WATERSHED_STATE_MIN", "min" },
            { GWY_WATERSHED_STATE_WATERSHED, "GWY_WATERSHED_STATE_WATERSHED", "watershed" },
            { GWY_WATERSHED_STATE_MARK, "GWY_WATERSHED_STATE_MARK", "mark" },
            { GWY_WATERSHED_STATE_FINISHED, "GWY_WATERSHED_STATE_FINISHED", "finished" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyWatershedStateType", values);
    }
    return etype;
}

GType
gwy_plane_symmetry_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_SYMMETRY_AUTO, "GWY_SYMMETRY_AUTO", "auto" },
            { GWY_SYMMETRY_PARALLEL, "GWY_SYMMETRY_PARALLEL", "parallel" },
            { GWY_SYMMETRY_TRIANGULAR, "GWY_SYMMETRY_TRIANGULAR", "triangular" },
            { GWY_SYMMETRY_SQUARE, "GWY_SYMMETRY_SQUARE", "square" },
            { GWY_SYMMETRY_RHOMBIC, "GWY_SYMMETRY_RHOMBIC", "rhombic" },
            { GWY_SYMMETRY_HEXAGONAL, "GWY_SYMMETRY_HEXAGONAL", "hexagonal" },
            { GWY_SYMMETRY_LAST, "GWY_SYMMETRY_LAST", "last" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyPlaneSymmetry", values);
    }
    return etype;
}

GType
gwy_2d_cwt_wavelet_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_2DCWT_GAUSS, "GWY_2DCWT_GAUSS", "gauss" },
            { GWY_2DCWT_HAT, "GWY_2DCWT_HAT", "hat" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("Gwy2DCWTWaveletType", values);
    }
    return etype;
}

GType
gwy_orientation_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_ORIENTATION_HORIZONTAL, "GWY_ORIENTATION_HORIZONTAL", "horizontal" },
            { GWY_ORIENTATION_VERTICAL, "GWY_ORIENTATION_VERTICAL", "vertical" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyOrientation", values);
    }
    return etype;
}

GType
gwy_transform_direction_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_TRANSFORM_DIRECTION_BACKWARD, "GWY_TRANSFORM_DIRECTION_BACKWARD", "backward" },
            { GWY_TRANSFORM_DIRECTION_FORWARD, "GWY_TRANSFORM_DIRECTION_FORWARD", "forward" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyTransformDirection", values);
    }
    return etype;
}

GType
gwy_data_field_cached_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_DATA_FIELD_CACHE_MIN, "GWY_DATA_FIELD_CACHE_MIN", "min" },
            { GWY_DATA_FIELD_CACHE_MAX, "GWY_DATA_FIELD_CACHE_MAX", "max" },
            { GWY_DATA_FIELD_CACHE_SUM, "GWY_DATA_FIELD_CACHE_SUM", "sum" },
            { GWY_DATA_FIELD_CACHE_RMS, "GWY_DATA_FIELD_CACHE_RMS", "rms" },
            { GWY_DATA_FIELD_CACHE_MED, "GWY_DATA_FIELD_CACHE_MED", "med" },
            { GWY_DATA_FIELD_CACHE_ARF, "GWY_DATA_FIELD_CACHE_ARF", "arf" },
            { GWY_DATA_FIELD_CACHE_ART, "GWY_DATA_FIELD_CACHE_ART", "art" },
            { GWY_DATA_FIELD_CACHE_ARE, "GWY_DATA_FIELD_CACHE_ARE", "are" },
            { GWY_DATA_FIELD_CACHE_VAR, "GWY_DATA_FIELD_CACHE_VAR", "var" },
            { GWY_DATA_FIELD_CACHE_ENT, "GWY_DATA_FIELD_CACHE_ENT", "ent" },
            { GWY_DATA_FIELD_CACHE_SIZE, "GWY_DATA_FIELD_CACHE_SIZE", "size" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyDataFieldCached", values);
    }
    return etype;
}

GType
gwy_computation_state_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_COMPUTATION_STATE_INIT, "GWY_COMPUTATION_STATE_INIT", "init" },
            { GWY_COMPUTATION_STATE_ITERATE, "GWY_COMPUTATION_STATE_ITERATE", "iterate" },
            { GWY_COMPUTATION_STATE_FINISHED, "GWY_COMPUTATION_STATE_FINISHED", "finished" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyComputationStateType", values);
    }
    return etype;
}

GType
gwy_dwt_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_DWT_HAAR, "GWY_DWT_HAAR", "haar" },
            { GWY_DWT_DAUB4, "GWY_DWT_DAUB4", "daub4" },
            { GWY_DWT_DAUB6, "GWY_DWT_DAUB6", "daub6" },
            { GWY_DWT_DAUB8, "GWY_DWT_DAUB8", "daub8" },
            { GWY_DWT_DAUB12, "GWY_DWT_DAUB12", "daub12" },
            { GWY_DWT_DAUB20, "GWY_DWT_DAUB20", "daub20" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyDWTType", values);
    }
    return etype;
}

GType
gwy_dwt_denoise_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_DWT_DENOISE_UNIVERSAL, "GWY_DWT_DENOISE_UNIVERSAL", "universal" },
            { GWY_DWT_DENOISE_SCALE_ADAPTIVE, "GWY_DWT_DENOISE_SCALE_ADAPTIVE", "scale-adaptive" },
            { GWY_DWT_DENOISE_SPACE_ADAPTIVE, "GWY_DWT_DENOISE_SPACE_ADAPTIVE", "space-adaptive" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyDWTDenoiseType", values);
    }
    return etype;
}

GType
gwy_interpolation_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_INTERPOLATION_NONE, "GWY_INTERPOLATION_NONE", "none" },
            { GWY_INTERPOLATION_ROUND, "GWY_INTERPOLATION_ROUND", "round" },
            { GWY_INTERPOLATION_LINEAR, "GWY_INTERPOLATION_LINEAR", "linear" },
            { GWY_INTERPOLATION_BILINEAR, "GWY_INTERPOLATION_BILINEAR", "bilinear" },
            { GWY_INTERPOLATION_KEY, "GWY_INTERPOLATION_KEY", "key" },
            { GWY_INTERPOLATION_BSPLINE, "GWY_INTERPOLATION_BSPLINE", "bspline" },
            { GWY_INTERPOLATION_OMOMS, "GWY_INTERPOLATION_OMOMS", "omoms" },
            { GWY_INTERPOLATION_NNA, "GWY_INTERPOLATION_NNA", "nna" },
            { GWY_INTERPOLATION_SCHAUM, "GWY_INTERPOLATION_SCHAUM", "schaum" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyInterpolationType", values);
    }
    return etype;
}

GType
gwy_plane_fit_quantity_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_PLANE_FIT_A, "GWY_PLANE_FIT_A", "a" },
            { GWY_PLANE_FIT_BX, "GWY_PLANE_FIT_BX", "bx" },
            { GWY_PLANE_FIT_BY, "GWY_PLANE_FIT_BY", "by" },
            { GWY_PLANE_FIT_ANGLE, "GWY_PLANE_FIT_ANGLE", "angle" },
            { GWY_PLANE_FIT_SLOPE, "GWY_PLANE_FIT_SLOPE", "slope" },
            { GWY_PLANE_FIT_S0, "GWY_PLANE_FIT_S0", "s0" },
            { GWY_PLANE_FIT_S0_REDUCED, "GWY_PLANE_FIT_S0_REDUCED", "s0-reduced" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyPlaneFitQuantity", values);
    }
    return etype;
}

GType
gwy_windowing_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_WINDOWING_NONE, "GWY_WINDOWING_NONE", "none" },
            { GWY_WINDOWING_HANN, "GWY_WINDOWING_HANN", "hann" },
            { GWY_WINDOWING_HAMMING, "GWY_WINDOWING_HAMMING", "hamming" },
            { GWY_WINDOWING_BLACKMANN, "GWY_WINDOWING_BLACKMANN", "blackmann" },
            { GWY_WINDOWING_LANCZOS, "GWY_WINDOWING_LANCZOS", "lanczos" },
            { GWY_WINDOWING_WELCH, "GWY_WINDOWING_WELCH", "welch" },
            { GWY_WINDOWING_RECT, "GWY_WINDOWING_RECT", "rect" },
            { GWY_WINDOWING_NUTTALL, "GWY_WINDOWING_NUTTALL", "nuttall" },
            { GWY_WINDOWING_FLAT_TOP, "GWY_WINDOWING_FLAT_TOP", "flat-top" },
            { GWY_WINDOWING_KAISER25, "GWY_WINDOWING_KAISER25", "kaiser25" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyWindowingType", values);
    }
    return etype;
}

GType
gwy_tip_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_TIP_PYRAMID, "GWY_TIP_PYRAMID", "pyramid" },
            { GWY_TIP_PYRAMIDE, "GWY_TIP_PYRAMIDE", "pyramide" },
            { GWY_TIP_CONTACT, "GWY_TIP_CONTACT", "contact" },
            { GWY_TIP_NONCONTACT, "GWY_TIP_NONCONTACT", "noncontact" },
            { GWY_TIP_DELTA, "GWY_TIP_DELTA", "delta" },
            { GWY_TIP_PARABOLA, "GWY_TIP_PARABOLA", "parabola" },
            { GWY_TIP_CONE, "GWY_TIP_CONE", "cone" },
            { GWY_TIP_ELLPARABOLA, "GWY_TIP_ELLPARABOLA", "ellparabola" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyTipType", values);
    }
    return etype;
}

GType
gwy_tip_param_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_TIP_PARAM_HEIGHT, "GWY_TIP_PARAM_HEIGHT", "height" },
            { GWY_TIP_PARAM_RADIUS, "GWY_TIP_PARAM_RADIUS", "radius" },
            { GWY_TIP_PARAM_ROTATION, "GWY_TIP_PARAM_ROTATION", "rotation" },
            { GWY_TIP_PARAM_NSIDES, "GWY_TIP_PARAM_NSIDES", "nsides" },
            { GWY_TIP_PARAM_SLOPE, "GWY_TIP_PARAM_SLOPE", "slope" },
            { GWY_TIP_PARAM_ANISOTROPY, "GWY_TIP_PARAM_ANISOTROPY", "anisotropy" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyTipParamType", values);
    }
    return etype;
}

GType
gwy_correlation_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_CORRELATION_NORMAL, "GWY_CORRELATION_NORMAL", "normal" },
            { GWY_CORRELATION_FFT, "GWY_CORRELATION_FFT", "fft" },
            { GWY_CORRELATION_POC, "GWY_CORRELATION_POC", "poc" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyCorrelationType", values);
    }
    return etype;
}

GType
gwy_grain_quantity_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_GRAIN_VALUE_PROJECTED_AREA, "GWY_GRAIN_VALUE_PROJECTED_AREA", "projected-area" },
            { GWY_GRAIN_VALUE_EQUIV_SQUARE_SIDE, "GWY_GRAIN_VALUE_EQUIV_SQUARE_SIDE", "equiv-square-side" },
            { GWY_GRAIN_VALUE_EQUIV_DISC_RADIUS, "GWY_GRAIN_VALUE_EQUIV_DISC_RADIUS", "equiv-disc-radius" },
            { GWY_GRAIN_VALUE_SURFACE_AREA, "GWY_GRAIN_VALUE_SURFACE_AREA", "surface-area" },
            { GWY_GRAIN_VALUE_MAXIMUM, "GWY_GRAIN_VALUE_MAXIMUM", "maximum" },
            { GWY_GRAIN_VALUE_MINIMUM, "GWY_GRAIN_VALUE_MINIMUM", "minimum" },
            { GWY_GRAIN_VALUE_MEAN, "GWY_GRAIN_VALUE_MEAN", "mean" },
            { GWY_GRAIN_VALUE_MEDIAN, "GWY_GRAIN_VALUE_MEDIAN", "median" },
            { GWY_GRAIN_VALUE_PIXEL_AREA, "GWY_GRAIN_VALUE_PIXEL_AREA", "pixel-area" },
            { GWY_GRAIN_VALUE_HALF_HEIGHT_AREA, "GWY_GRAIN_VALUE_HALF_HEIGHT_AREA", "half-height-area" },
            { GWY_GRAIN_VALUE_FLAT_BOUNDARY_LENGTH, "GWY_GRAIN_VALUE_FLAT_BOUNDARY_LENGTH", "flat-boundary-length" },
            { GWY_GRAIN_VALUE_MINIMUM_BOUND_SIZE, "GWY_GRAIN_VALUE_MINIMUM_BOUND_SIZE", "minimum-bound-size" },
            { GWY_GRAIN_VALUE_MINIMUM_BOUND_ANGLE, "GWY_GRAIN_VALUE_MINIMUM_BOUND_ANGLE", "minimum-bound-angle" },
            { GWY_GRAIN_VALUE_MAXIMUM_BOUND_SIZE, "GWY_GRAIN_VALUE_MAXIMUM_BOUND_SIZE", "maximum-bound-size" },
            { GWY_GRAIN_VALUE_MAXIMUM_BOUND_ANGLE, "GWY_GRAIN_VALUE_MAXIMUM_BOUND_ANGLE", "maximum-bound-angle" },
            { GWY_GRAIN_VALUE_CENTER_X, "GWY_GRAIN_VALUE_CENTER_X", "center-x" },
            { GWY_GRAIN_VALUE_CENTER_Y, "GWY_GRAIN_VALUE_CENTER_Y", "center-y" },
            { GWY_GRAIN_VALUE_VOLUME_0, "GWY_GRAIN_VALUE_VOLUME_0", "volume-0" },
            { GWY_GRAIN_VALUE_VOLUME_MIN, "GWY_GRAIN_VALUE_VOLUME_MIN", "volume-min" },
            { GWY_GRAIN_VALUE_VOLUME_LAPLACE, "GWY_GRAIN_VALUE_VOLUME_LAPLACE", "volume-laplace" },
            { GWY_GRAIN_VALUE_SLOPE_THETA, "GWY_GRAIN_VALUE_SLOPE_THETA", "slope-theta" },
            { GWY_GRAIN_VALUE_SLOPE_PHI, "GWY_GRAIN_VALUE_SLOPE_PHI", "slope-phi" },
            { GWY_GRAIN_VALUE_BOUNDARY_MAXIMUM, "GWY_GRAIN_VALUE_BOUNDARY_MAXIMUM", "boundary-maximum" },
            { GWY_GRAIN_VALUE_BOUNDARY_MINIMUM, "GWY_GRAIN_VALUE_BOUNDARY_MINIMUM", "boundary-minimum" },
            { GWY_GRAIN_VALUE_CURVATURE_CENTER_X, "GWY_GRAIN_VALUE_CURVATURE_CENTER_X", "curvature-center-x" },
            { GWY_GRAIN_VALUE_CURVATURE_CENTER_Y, "GWY_GRAIN_VALUE_CURVATURE_CENTER_Y", "curvature-center-y" },
            { GWY_GRAIN_VALUE_CURVATURE_CENTER_Z, "GWY_GRAIN_VALUE_CURVATURE_CENTER_Z", "curvature-center-z" },
            { GWY_GRAIN_VALUE_CURVATURE1, "GWY_GRAIN_VALUE_CURVATURE1", "curvature1" },
            { GWY_GRAIN_VALUE_CURVATURE2, "GWY_GRAIN_VALUE_CURVATURE2", "curvature2" },
            { GWY_GRAIN_VALUE_CURVATURE_ANGLE1, "GWY_GRAIN_VALUE_CURVATURE_ANGLE1", "curvature-angle1" },
            { GWY_GRAIN_VALUE_CURVATURE_ANGLE2, "GWY_GRAIN_VALUE_CURVATURE_ANGLE2", "curvature-angle2" },
            { GWY_GRAIN_VALUE_INSCRIBED_DISC_R, "GWY_GRAIN_VALUE_INSCRIBED_DISC_R", "inscribed-disc-r" },
            { GWY_GRAIN_VALUE_INSCRIBED_DISC_X, "GWY_GRAIN_VALUE_INSCRIBED_DISC_X", "inscribed-disc-x" },
            { GWY_GRAIN_VALUE_INSCRIBED_DISC_Y, "GWY_GRAIN_VALUE_INSCRIBED_DISC_Y", "inscribed-disc-y" },
            { GWY_GRAIN_VALUE_CONVEX_HULL_AREA, "GWY_GRAIN_VALUE_CONVEX_HULL_AREA", "convex-hull-area" },
            { GWY_GRAIN_VALUE_CIRCUMCIRCLE_R, "GWY_GRAIN_VALUE_CIRCUMCIRCLE_R", "circumcircle-r" },
            { GWY_GRAIN_VALUE_CIRCUMCIRCLE_X, "GWY_GRAIN_VALUE_CIRCUMCIRCLE_X", "circumcircle-x" },
            { GWY_GRAIN_VALUE_CIRCUMCIRCLE_Y, "GWY_GRAIN_VALUE_CIRCUMCIRCLE_Y", "circumcircle-y" },
            { GWY_GRAIN_VALUE_MEAN_RADIUS, "GWY_GRAIN_VALUE_MEAN_RADIUS", "mean-radius" },
            { GWY_GRAIN_VALUE_EQUIV_ELLIPSE_MAJOR, "GWY_GRAIN_VALUE_EQUIV_ELLIPSE_MAJOR", "equiv-ellipse-major" },
            { GWY_GRAIN_VALUE_EQUIV_ELLIPSE_MINOR, "GWY_GRAIN_VALUE_EQUIV_ELLIPSE_MINOR", "equiv-ellipse-minor" },
            { GWY_GRAIN_VALUE_EQUIV_ELLIPSE_ANGLE, "GWY_GRAIN_VALUE_EQUIV_ELLIPSE_ANGLE", "equiv-ellipse-angle" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyGrainQuantity", values);
    }
    return etype;
}

GType
gwy_data_compatibility_flags_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GFlagsValue values[] = {
            { GWY_DATA_COMPATIBILITY_RES, "GWY_DATA_COMPATIBILITY_RES", "res" },
            { GWY_DATA_COMPATIBILITY_REAL, "GWY_DATA_COMPATIBILITY_REAL", "real" },
            { GWY_DATA_COMPATIBILITY_MEASURE, "GWY_DATA_COMPATIBILITY_MEASURE", "measure" },
            { GWY_DATA_COMPATIBILITY_LATERAL, "GWY_DATA_COMPATIBILITY_LATERAL", "lateral" },
            { GWY_DATA_COMPATIBILITY_VALUE, "GWY_DATA_COMPATIBILITY_VALUE", "value" },
            { GWY_DATA_COMPATIBILITY_ALL, "GWY_DATA_COMPATIBILITY_ALL", "all" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static("GwyDataCompatibilityFlags", values);
    }
    return etype;
}

GType
gwy_line_stat_quantity_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_LINE_STAT_MEAN, "GWY_LINE_STAT_MEAN", "mean" },
            { GWY_LINE_STAT_MEDIAN, "GWY_LINE_STAT_MEDIAN", "median" },
            { GWY_LINE_STAT_MINIMUM, "GWY_LINE_STAT_MINIMUM", "minimum" },
            { GWY_LINE_STAT_MAXIMUM, "GWY_LINE_STAT_MAXIMUM", "maximum" },
            { GWY_LINE_STAT_RMS, "GWY_LINE_STAT_RMS", "rms" },
            { GWY_LINE_STAT_LENGTH, "GWY_LINE_STAT_LENGTH", "length" },
            { GWY_LINE_STAT_SLOPE, "GWY_LINE_STAT_SLOPE", "slope" },
            { GWY_LINE_STAT_TAN_BETA0, "GWY_LINE_STAT_TAN_BETA0", "tan-beta0" },
            { GWY_LINE_STAT_RA, "GWY_LINE_STAT_RA", "ra" },
            { GWY_LINE_STAT_RZ, "GWY_LINE_STAT_RZ", "rz" },
            { GWY_LINE_STAT_RT, "GWY_LINE_STAT_RT", "rt" },
            { GWY_LINE_STAT_SKEW, "GWY_LINE_STAT_SKEW", "skew" },
            { GWY_LINE_STAT_KURTOSIS, "GWY_LINE_STAT_KURTOSIS", "kurtosis" },
            { GWY_LINE_STAT_RANGE, "GWY_LINE_STAT_RANGE", "range" },
            { GWY_LINE_STAT_VARIATION, "GWY_LINE_STAT_VARIATION", "variation" },
            { GWY_LINE_STAT_MINPOS, "GWY_LINE_STAT_MINPOS", "minpos" },
            { GWY_LINE_STAT_MAXPOS, "GWY_LINE_STAT_MAXPOS", "maxpos" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyLineStatQuantity", values);
    }
    return etype;
}

GType
gwy_exterior_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_EXTERIOR_UNDEFINED, "GWY_EXTERIOR_UNDEFINED", "undefined" },
            { GWY_EXTERIOR_BORDER_EXTEND, "GWY_EXTERIOR_BORDER_EXTEND", "border-extend" },
            { GWY_EXTERIOR_MIRROR_EXTEND, "GWY_EXTERIOR_MIRROR_EXTEND", "mirror-extend" },
            { GWY_EXTERIOR_PERIODIC, "GWY_EXTERIOR_PERIODIC", "periodic" },
            { GWY_EXTERIOR_FIXED_VALUE, "GWY_EXTERIOR_FIXED_VALUE", "fixed-value" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyExteriorType", values);
    }
    return etype;
}

GType
gwy_distance_transform_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_DISTANCE_TRANSFORM_CITYBLOCK, "GWY_DISTANCE_TRANSFORM_CITYBLOCK", "cityblock" },
            { GWY_DISTANCE_TRANSFORM_CONN4, "GWY_DISTANCE_TRANSFORM_CONN4", "conn4" },
            { GWY_DISTANCE_TRANSFORM_CHESS, "GWY_DISTANCE_TRANSFORM_CHESS", "chess" },
            { GWY_DISTANCE_TRANSFORM_CONN8, "GWY_DISTANCE_TRANSFORM_CONN8", "conn8" },
            { GWY_DISTANCE_TRANSFORM_OCTAGONAL48, "GWY_DISTANCE_TRANSFORM_OCTAGONAL48", "octagonal48" },
            { GWY_DISTANCE_TRANSFORM_OCTAGONAL84, "GWY_DISTANCE_TRANSFORM_OCTAGONAL84", "octagonal84" },
            { GWY_DISTANCE_TRANSFORM_OCTAGONAL, "GWY_DISTANCE_TRANSFORM_OCTAGONAL", "octagonal" },
            { GWY_DISTANCE_TRANSFORM_EUCLIDEAN, "GWY_DISTANCE_TRANSFORM_EUCLIDEAN", "euclidean" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyDistanceTransformType", values);
    }
    return etype;
}

GType
gwy_min_max_filter_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_MIN_MAX_FILTER_MINIMUM, "GWY_MIN_MAX_FILTER_MINIMUM", "minimum" },
            { GWY_MIN_MAX_FILTER_EROSION, "GWY_MIN_MAX_FILTER_EROSION", "erosion" },
            { GWY_MIN_MAX_FILTER_MAXIMUM, "GWY_MIN_MAX_FILTER_MAXIMUM", "maximum" },
            { GWY_MIN_MAX_FILTER_DILATION, "GWY_MIN_MAX_FILTER_DILATION", "dilation" },
            { GWY_MIN_MAX_FILTER_OPENING, "GWY_MIN_MAX_FILTER_OPENING", "opening" },
            { GWY_MIN_MAX_FILTER_CLOSING, "GWY_MIN_MAX_FILTER_CLOSING", "closing" },
            { GWY_MIN_MAX_FILTER_RANGE, "GWY_MIN_MAX_FILTER_RANGE", "range" },
            { GWY_MIN_MAX_FILTER_NORMALIZATION, "GWY_MIN_MAX_FILTER_NORMALIZATION", "normalization" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyMinMaxFilterType", values);
    }
    return etype;
}

GType
gwy_rotate_resize_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_ROTATE_RESIZE_SAME_SIZE, "GWY_ROTATE_RESIZE_SAME_SIZE", "same-size" },
            { GWY_ROTATE_RESIZE_EXPAND, "GWY_ROTATE_RESIZE_EXPAND", "expand" },
            { GWY_ROTATE_RESIZE_CUT, "GWY_ROTATE_RESIZE_CUT", "cut" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyRotateResizeType", values);
    }
    return etype;
}

GType
gwy_affine_scaling_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_AFFINE_SCALING_AS_GIVEN, "GWY_AFFINE_SCALING_AS_GIVEN", "as-given" },
            { GWY_AFFINE_SCALING_PRESERVE_AREA, "GWY_AFFINE_SCALING_PRESERVE_AREA", "preserve-area" },
            { GWY_AFFINE_SCALING_PRESERVE_X, "GWY_AFFINE_SCALING_PRESERVE_X", "preserve-x" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyAffineScalingType", values);
    }
    return etype;
}

#include "./peaks.h"

GType
gwy_peak_background_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_PEAK_BACKGROUND_ZERO, "GWY_PEAK_BACKGROUND_ZERO", "zero" },
            { GWY_PEAK_BACKGROUND_MMSTEP, "GWY_PEAK_BACKGROUND_MMSTEP", "mmstep" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyPeakBackgroundType", values);
    }
    return etype;
}

GType
gwy_peak_order_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_PEAK_ORDER_ABSCISSA, "GWY_PEAK_ORDER_ABSCISSA", "abscissa" },
            { GWY_PEAK_ORDER_PROMINENCE, "GWY_PEAK_ORDER_PROMINENCE", "prominence" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyPeakOrderType", values);
    }
    return etype;
}

GType
gwy_peak_quantity_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_PEAK_PROMINENCE, "GWY_PEAK_PROMINENCE", "prominence" },
            { GWY_PEAK_ABSCISSA, "GWY_PEAK_ABSCISSA", "abscissa" },
            { GWY_PEAK_HEIGHT, "GWY_PEAK_HEIGHT", "height" },
            { GWY_PEAK_AREA, "GWY_PEAK_AREA", "area" },
            { GWY_PEAK_WIDTH, "GWY_PEAK_WIDTH", "width" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyPeakQuantity", values);
    }
    return etype;
}

#include "./gwygrainvalue.h"

GType
gwy_grain_value_group_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_GRAIN_VALUE_GROUP_ID, "GWY_GRAIN_VALUE_GROUP_ID", "id" },
            { GWY_GRAIN_VALUE_GROUP_POSITION, "GWY_GRAIN_VALUE_GROUP_POSITION", "position" },
            { GWY_GRAIN_VALUE_GROUP_VALUE, "GWY_GRAIN_VALUE_GROUP_VALUE", "value" },
            { GWY_GRAIN_VALUE_GROUP_AREA, "GWY_GRAIN_VALUE_GROUP_AREA", "area" },
            { GWY_GRAIN_VALUE_GROUP_VOLUME, "GWY_GRAIN_VALUE_GROUP_VOLUME", "volume" },
            { GWY_GRAIN_VALUE_GROUP_BOUNDARY, "GWY_GRAIN_VALUE_GROUP_BOUNDARY", "boundary" },
            { GWY_GRAIN_VALUE_GROUP_SLOPE, "GWY_GRAIN_VALUE_GROUP_SLOPE", "slope" },
            { GWY_GRAIN_VALUE_GROUP_CURVATURE, "GWY_GRAIN_VALUE_GROUP_CURVATURE", "curvature" },
            { GWY_GRAIN_VALUE_GROUP_MOMENT, "GWY_GRAIN_VALUE_GROUP_MOMENT", "moment" },
            { GWY_GRAIN_VALUE_GROUP_USER, "GWY_GRAIN_VALUE_GROUP_USER", "user" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyGrainValueGroup", values);
    }
    return etype;
}

GType
gwy_grain_value_flags_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GFlagsValue values[] = {
            { GWY_GRAIN_VALUE_SAME_UNITS, "GWY_GRAIN_VALUE_SAME_UNITS", "same-units" },
            { GWY_GRAIN_VALUE_IS_ANGLE, "GWY_GRAIN_VALUE_IS_ANGLE", "is-angle" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static("GwyGrainValueFlags", values);
    }
    return etype;
}


/* Generated data ends here */

